@@ -50,7 +50,7 @@ class Client:
             # Create new connection
             self.client = self.context.socket(zmq.REQ)
             self.client.connect(SERVER_ENDPOINT)
-            logging.info("Resending (%s)", request)
+            logging.debug("Resending (%s)", request)
             self.client.send(request)
 
     def close(self):
@@ -111,8 +111,8 @@ class JSONTranslator:
                                         description='A valid JSON document is required.')
 
         try:
-            req.context.doc = json.loads(body.decode('utf-8'))
-
+            # req.context.doc = json.loads(body.decode('utf-8'))
+            req.context.doc = body.decode('utf-8')
         except (ValueError, UnicodeDecodeError):
             description = ('Could not decode the request body. The '
                            'JSON was incorrect or not encoded as '
@@ -142,6 +142,9 @@ def max_body(limit):
 
 class Prediction:
 
+    def __init__(self, concurrent):
+        self.concurrent = concurrent
+
     async def on_get(self, req, resp):
         """Handles GET requests"""
         resp.status = falcon.HTTP_200  # This is the default status
@@ -152,20 +155,24 @@ class Prediction:
                      '    By Faith\n\n')
 
     
-    @falcon.before(max_body(64 * 1024))
+    @falcon.before(max_body(20 * 1024 * 1024))
     async def on_post(self, req, resp):
         result = ''
         try:
             json_str = req.context.doc
             # print('---', json_str)
-            logging.debug(req, json_str)
-
+            # logging.debug(req, json_str)
             result = self.concurrent.send_request(json_str.encode())
-
+            
             if type(result) == bytes:
-                result = json.loads(result.decode('utf-8'))
+                try:
+                    result = json.loads(result.decode('utf-8'))
+                except Exception as e:
+                    result = result.decode('utf-8')
+       
             # print(doc, type(doc), doc['test'])
-        except AttributeError:
+        except AttributeError as e:
+            print(e)
             raise falcon.HTTPBadRequest(
                 title='Missing thing',
                 description='A thing must be submitted in the request body.')
@@ -190,7 +197,7 @@ class HTTPProxy(Process):
             JSONTranslator(),
         ])
         # Resources are represented by long-lived class instances
-        prediction = Prediction()
+        prediction = Prediction(self.concurrent)
 
         # things will handle all requests to the '/things' URL path
         app.add_route('/predict', prediction)
@@ -227,6 +234,7 @@ class HTTPProxy(Process):
                 if type(result) == bytes:
                     result = json.loads(result.decode('utf-8'))
                     return result
+                print('result--', result)
                 return result
             except Exception as e:
                 print(e)
@@ -237,7 +245,7 @@ class HTTPProxy(Process):
 
     def run(self):
         import uvicorn
-        app = self.create_app()
         self.concurrent = ConcurrentClient(max_concurrency = self.args.max_connect)
+        app = self.create_app()
         self.is_ready.set()
         uvicorn.run(app, host="0.0.0.0", port=self.args.http_port)
